@@ -38,7 +38,6 @@ ALL_FIELDS = [
     fields.Integer,
     fields.Boolean,
     fields.Float,
-    fields.Number,
     fields.DateTime,
     fields.Time,
     fields.Date,
@@ -180,7 +179,7 @@ def get_lowername(obj):
 
 class UserSchema(Schema):
     name = fields.String()
-    age = fields.Float()  # type: fields.Field
+    age: fields.Field = fields.Float()
     created = fields.DateTime()
     created_formatted = fields.DateTime(
         format="%Y-%m-%d", attribute="created", dump_only=True
@@ -193,7 +192,7 @@ class UserSchema(Schema):
     homepage = fields.Url()
     email = fields.Email()
     balance = fields.Decimal()
-    is_old = fields.Method("get_is_old")  # type: fields.Field
+    is_old: fields.Field = fields.Method("get_is_old")
     lowername = fields.Function(get_lowername)
     registered = fields.Boolean()
     hair_colors = fields.List(fields.Raw)
